OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Záložky",
    "You bookmarked \"%s\"" : "Přidali jste „%s“ do záložek",
    "%1$s bookmarked \"%2$s\"" : "%1$s přidal(a) „%2$s“ do záložek",
    "Someone bookmarked \"%s\"" : "Někdo přidal „%s“ do záložek",
    "You deleted \"%s\"" : "Smazali jste „%s“",
    "%1$s deleted \"%2$s\"" : "%1$s smazal(a) „%2$s“",
    "Someone deleted \"%s\"" : "Někdo smazal „%s“",
    "You created folder \"%s\"" : "Vytvořili jste složku „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s vytvořil(a) složku „%2$s“",
    "Someone created folder \"%s\"" : "Někdo vytvořil složku „%s“",
    "You moved folder \"%s\"" : "Přesunuli jste složku „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s přesunul(a) složku „%2$s“",
    "Someone moved folder \"%s\"" : "Někdo přesunul složku „%s“",
    "You deleted folder \"%s\"" : "Smazali jste složku „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s smazal(a) složku „%2$s“",
    "Someone deleted folder \"%s\"" : "Někdo smazal složku „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Nasdíleli jste složku „%1$s“ uživateli/skupině %2$s",
    "You shared folder \"%s\" with someone" : "Nasdíleli jste složku „%s“ někomu",
    "%1$s shared folder \"%2$s\" with you" : "%1$s vám nasdílel(a) složku „%2$s“",
    "Someone shared folder \"%s\" with you" : "Někdo vám nasdílel složku „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Zrušili jste sdílení složky „%1$s“ pro %2$s",
    "You unshared folder \"%s\" with someone" : "Zrušili jste sdílení složky „%s“ někomu",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s zrušil(a) sdílení složky „%2$s“ vám",
    "Someone unshared folder \"%s\" with you" : "Někdo zrušil sdílení složky „%s“ vám",
    "No file provided for import" : "Nezadali jste soubor k importu",
    "Failed to upload file" : "Nepodařilo se nahrát soubor",
    "Unsupported file type for import: " : "Nepodporovaný typ souboru pro import:",
    "Bookmarks shared by %s" : "Záložky, které sdílí %s",
    "Frequent bookmarks" : "Často využívané záložky",
    "Recent bookmarks" : "Nedávné záložky",
    "Bookmark" : "Záložka",
    "Bookmark deleted" : "Záložka smazána",
    "Bookmark created" : "Záložka vytvořena",
    "Bookmark moved" : "Záložka přesunuta",
    "Bookmark updated" : "Záložka aktualizována",
    "Create bookmark" : "Vytvořit záložku",
    "Takes a link and adds it to your collection of bookmarks." : "Vezme odkaz a přidá ho do vaší sbírky záložek.",
    "Bookmarks Backups" : "Zálohy záložek",
    "Collect and manage bookmarks, synced with all your devices" : "Shromažďujte a spravujte záložky – synchronizováno se všemi vašimi zařízeními",
    "Enter new title" : "Zadejte nový titulek",
    "Select bookmark" : "Vybrat záložku",
    "You have never clicked this link" : "Na tento odkaz jste ještě nikdy neklikli",
    "You have clicked this link {count} times" : "Na tento odkaz jste klili {count} krát",
    "Details" : "Podrobnosti",
    "Rename" : "Přejmenovat",
    "Copy link" : "Zkopírovat odkaz",
    "Move" : "Přesunout",
    "Add to folders" : "Přidat složek",
    "Put bookmark into trash bin" : "Přemístit záložku do koše",
    "Restore bookmark" : "Obnovit záložku",
    "Delete bookmark permanently" : "Smazat záložku nevratně",
    "Do you really want to delete this bookmark?" : "Opravdu chcete tuto záložku smazat?",
    "Link copied to clipboard" : "Odkaz zkopírován do schánky",
    "Content pending" : "Obsah čeká na vyřízení",
    "This content is being downloaded for offline use. Please check back later." : "Tento obsah je stahován pro použití bez připojení. Vraťte se sem později.",
    "Bookmarked {time} ago" : "Zařazeno do záložek před {time}",
    "Bookmarked on {date}" : "Zařazeno do záložek {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Toto jsou vámi smazané položky. Po uplynutí dvou měsíců budou natrvalo smazány.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Soubory, jako jsou fotky či PDF dokumenty na webu budou automaticky uloženy mezi vaše soubory v Nextcloud, takže budou k dispozici i když cíl odkazu přestane být dostupný.",
    "Searching in the current folder only." : "Hledá se pouze ve stávající složce.",
    "Repeat search in all folders" : "Zopakovat hledání ve všech složkách",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Odkazy uložené do záložek jsou pravidelně kontrolovány a ty, které jsou nedosažitelné jsou uvedené zde.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Složky se záložkami je možné nasdílet ostatním. Veškeré vám nasdílené složky jsou vypsané zde.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Jedna záložka se může nacházet ve vícero složkách naráz. Její aktualizace se propíše do všech výskytů. Pro snadnou dosažitelnost jsou veškeré duplicitní záložky vypsány zde.",
    "Open all selected" : "Otevřít vše vybrané",
    "Move selection" : "Přesunout vybrané",
    "Edit tags of selection" : "Upravit štítky výběru",
    "Delete selection" : "Smazat výběr",
    "Select all" : "Vybrat vše",
    "Cancel selection" : "Zrušit výběr",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Vybráno {folders} složek a {bookmarks} záložek",
    "Do you really want to delete these items?" : "Opravdu chcete tyto položky smazat?",
    "Trash Bin" : "Koš",
    "Go back" : "Jít zpět",
    "Share folder" : "Sdílet složku",
    "Open folder details" : "Otevřít podrobnosti složky",
    "Select one or more tags" : "Vyberte jeden nebo více štítků",
    "New" : "Nová",
    "New bookmark" : "Nová záložka",
    "New folder" : "Nová složka",
    "Change to grid view" : "Přepnout na zobrazení v mřížce",
    "Change to list view" : "Přepnout do zobrazení v seznamu",
    "Copy RSS Feed of current view" : "Zkopírovat RSS kanál stávajícího pohledu",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS kanál vyžaduje ověření se prostřednictvím vašich přihlašovacích údajů do Nextcloud",
    "Search" : "Hledat",
    "Empty trash bin" : "Vyprázdnit koš",
    "Sort by created date" : "Seřadit podle data vytvoření",
    "Sort by last modified" : "Seřadit podle okamžiku poslední úpravy",
    "Sort by title" : "Seřadit podle nadpisu",
    "Sort by click count" : "Seřadit podle počtu kliknutí",
    "Sort by manual order" : "Seřadit ručně",
    "Sort by URL" : "Seřadit podle URL",
    "RSS feed copied" : "RSS kanál zkopírován",
    "Enter a link" : "Zadejte odkaz",
    "Enter a title" : "Zadejte titulek",
    "No bookmarks found" : "Nenalezeny žádné záložky",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} složek a {bookmarks} záložek",
    "Welcome to Bookmarks" : "Vítejte v Záložkách",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Tato aplikace umožňuje spravovat si odkazy na svá oblíbená místa na webu. Uspořádávejte si své záložky do složek, opatřete je štítky a sdílejte je s ostatními! Aplikace pravidelně kontroluje, zda jsou odkazy stále ještě funkční a zobrazí ty, které nejsou. Pokud přidáte odkaz na soubor na webu, soubor bude automaticky stažen do Nextcloud Soubory. Pomocí aplikace Záložky je také možné naimportovat záložky exportované z ostatních služeb nebo přímo synchronizovat záložky ze všech vašich prohlížečů.",
    "Add a bookmark" : "Přidat do záložek",
    "Import bookmarks" : "Importovat záložky",
    "Sync with your browser" : "Synchronizovat s prohlížečem",
    "Select folder" : "Vyberte složku",
    "Enter folder title" : "Zadejte název složky",
    "Shared by {user}" : "Sdílí {user}",
    "Rename folder" : "Přejmenovat složku",
    "Move folder" : "Přesunout složku",
    "Put folder into trashbin" : "Přemístit složku do koše",
    "Restore folder" : "Obnovit složku",
    "Delete folder permanently" : "Smazat složku nevratně",
    "Do you really want to permanently delete this folder?" : "Opravdu chcete tuto složku nevratně smazat?",
    "Choose folder" : "Zvolte složku",
    "Submit" : "Odeslat",
    "Cancel" : "Storno",
    "Deleting bookmarks" : "Mazání záložek",
    "Deleting selection" : "Mazání výběru",
    "Importing bookmarks" : "Importování záložek",
    "Moving selection" : "Přesouvání vybraných",
    "Adding selection to folders" : "Přidává se výběr do složek",
    "Emptying trashbin" : "Vyprazdňování koše",
    "All bookmarks" : "Všechny záložky",
    "Recent" : "Nedávné",
    "Shared with you" : "Nasdíleno vám",
    "Files" : "Soubory",
    "Duplicates" : "Duplicity",
    "Broken links" : "Nefunkční odkazy",
    "New tag" : "Nový štítek",
    "Search tags" : "Hledat štítky",
    "Delete" : "Smazat",
    "Untagged" : "Neoštítkováno",
    "{used} bookmarks of {available} available" : "{used} záložek z {available} k dispozici",
    "Bookmarks Settings" : "Nastavení pro záložky",
    "No bookmarked files" : "Žádné záložky na soubory",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Soubory, jako jsou fotky či PDF dokumenty, na které odkaz míří, budou automaticky uloženy mezi vaše soubory v Nextcloud, takže budou k dispozici i když cíl odkazu přestane být dostupný.",
    "Nothing found" : "Nic nenalezeno",
    "Your search yielded no results in the current folder." : "Pro vaše vyhledávání nebyl ve stávající složce nalezeny žádné výsledky.",
    "No broken links" : "Žádné nefunkční odkazy",
    "No shared folders" : "Žádné sdílené složky",
    "No duplicated bookmarks" : "Žádné duplicitní záložky",
    "No deleted bookmarks" : "Žádné smazané záložky",
    "You haven't deleted anything yet." : "Zatím jste ještě nic nesmazali.",
    "No bookmarks here" : "Nejsou zde žádné záložky",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Záložky přidávejte ručně nebo je naimportujte z HTML souboru.",
    "Bookmarks settings" : "Nastavení pro záložky",
    "Import/Export" : "Import/Export",
    "Export bookmarks" : "Exportovat záložky",
    "Auto-archiving" : "Automatická archivace",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Aplikace záložky může automaticky archivovat webový obsah odkazů, které jste si dali do záložek",
    "Enable archiving" : "Zapnout archivování",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Zadejte popis umístění složky ve svých Souborech, ve které by měly být uchovávány soubory, umístěné do záložek",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "V tuto chvíli je přístup k této aplikaci po síti vaším správcem vypnutý a proto je je automatické archivování vypnuté.",
    "Auto-Backup" : "Automatická záloha",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikace Záložky může provádět každodenní automatickou zálohu vašich záložek a bránit tak ztrátě dat při jejich synchronizaci napříč zařízeními.",
    "Enable backups" : "Zapnout zálohování",
    "Enter the path of a folder in your Files where backups will be stored." : "Zadejte popis umístění složky ve svých Souborech, do kterého ukládat zálohy.",
    "Client apps" : "Klientské aplikace",
    "Also check out the collection of client apps that integrate with this app: " : "Také se podívejte na sadu klientských aplikací, které napojují na tuto aplikaci:",
    "Install web app" : "Nainstalovat webovou aplikaci",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Tuto aplikaci můžete nainstalovat na domovskou obrazovku svého zařízení a získat tak rychlý přístup ke svým záložkám na telefonu. Pokud by se vám to nelíbilo, můžete aplikaci z domovské obrazovky zase snadno odstranit.",
    "Install on home screen" : "Nainstalovat na domovskou obrazovku",
    "Bookmarklet" : "Miniaplikace v záložce (bookmarklet)",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Toto přetáhněte do záložek svého prohlížeče a kliknutím přidejte stránku do záložek.",
    "Add to {instanceName}" : "Přidat do {instanceName}",
    "Need help?" : "Potřebujete nápovědu?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Pokud máte s aplikací Záložky problémy nebo máte nápad ohledně jejího vylepšení, neváhejte nás kontaktovat a to kliknutím sem.",
    "Support this project" : "Podpořte tento projekt",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Moje práce na této aplikaci Záložky je poháněna modelem dobrovolného předplatného. Pokud si myslíte, že to, co dělám má význam, potěšilo by mne pokud byste mou práci podpořili. Také prosím zvažte ohodnocení aplikace v katalogu aplikací pro Nextcloud. Děkuji 💙",
    "Archive path" : "Popis umístění archivu",
    "Backup path" : "Popis umístění záloh",
    "Please select \"Add to home screen\" in your browser menu" : "Z nabídky webového prohlížeče vyberte „Přidat na domovskou obrazovku“",
    "(Empty title)" : "(Prázný nadpis)",
    "Title" : "Nadpis",
    "Link" : "Odkaz",
    "Untitled folder" : "Složka bez názvu",
    "Root folder" : "Kořenová složka",
    "Tags" : "Štítky",
    "Select tags and create new ones" : "Vybírejte štítky a vytvářejte nové",
    "Notes" : "Poznámky",
    "Notes for this bookmark …" : "Poznámky k této záložce…",
    "Archived file" : "Zaarchivovaný soubor",
    "Download file" : "Stáhnout si soubor",
    "Open file location" : "Otevřít umístění souboru",
    "Created {time} ago" : "Vytvořeno před {time}",
    "Created on {date}" : "Vytvořeno {date}",
    "Owner" : "Vlastník",
    "Sharing" : "Sdílení",
    "Select a user or group" : "Vybrat uživatele nebo skupinu",
    "Share link" : "Odkaz na sdílení",
    "Reading allowed" : "Čtení umožněno",
    "Copy RSS feed" : "Zkopírovat RSS kanál",
    "Delete link" : "Smazat odkaz",
    "Create public link" : "Vytvořit veřejný odkaz",
    "Resharing allowed" : "Příjemcům tohoto sdílení je dovoleno ho nasdílet dál dalším",
    "Editing allowed" : "Upravování umožněno",
    "Allow editing" : "Povolit úpravy",
    "Allow resharing" : "Povolit příjemcům tohoto sdílení, aby sami mohli sdílet dalším",
    "Remove share" : "Odebrat sdílení",
    "Link copied" : "Odkaz zkopírován",
    "Privacy" : "Soukromí",
    "The app will try to access web pages that you add to automatically add information about them." : "Aplikace se pokusí přistoupit k webovým stránkám které přidáte a automaticky tak přidat informace o nich.",
    "Enable accessing and collecting information from the web pages you add" : "Zapnout přístup a shromažďování informací z webových stránek, které přidáte",
    "Performance" : "Výkonnost",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "U instalace s mnoha uživateli může být užitečné omezit počet záložek pro jednotlivé účty.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nejvyšší umožněný počet záložek v jednotlivých účtech (pro bez omezení 0, výchozí je právě bez limitu)",
    "Previews" : "Náhledy",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Pro zobrazování skutečných snímků obrazovky webů, které máte v záložkách, aplikace může použít pro vytváření náhledů služby třetích stran.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Je možné se buď bezplatně zaregistrovat na screeenly.com nebo si vytvořit vlastní server.",
    "Screeenly API URL" : "URL adresa aplikačního program. rozhraní (API) služby Screenly",
    "Screeenly API key" : "Klíč k aplikačnímu program. rozhraní (API) služby Screenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Klíč k API rozhraní služby ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL adresa API rozhraní služby Webshot",
    "Generic screenshot API" : "Obecné API rozhraní pro snímky obrazovky",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Vytvořte si účet u libovolného poskytovatele API rozhraní snímků obrazovky a URL API vložte níže. Jako zástupné vyjádření URL, které pořídit snímek obrazovky, použijte proměnnou {url}. Je třeba, aby API přímo vracelo obrázek a nic jiného.",
    "Generic API URL" : "URL obecného API rozhraní pro snímky obrazovky",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Stačí si na server nainstalovat Pageres CLI od Sindreho Sorhuse a Záložky ho použijí. I tak je možné přidávat další proměnné prostředí, které předat pageres, např. jako naznačeno v zástupném vyjádření:",
    "Pageres ENV variables" : "Proměnné prostředí pro pageres",
    "Failed to save settings" : "Nastavení se nepodařilo uložit",
    "Failed to load settings" : "Nepodařilo se načíst nastavení",
    "This URL is already bookmarked! Overwrite?" : "Adresa URL stánky už je v záložkách! Přepsat ?",
    "Enter bookmark title" : "Zadejte název záložky",
    "Enter bookmark URL" : "Zadejte URL pro záložku",
    "Folder" : "Složka",
    "Root Folder" : "Kořenová složka",
    "Save" : "Uložit",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Přístup k síti je ve výchozím stavu vypnut. Pokud chcete umožnit stahování náhledů a ikon webů, jděte do nastavení správy aplikace Záložky a zapněte ho tam.",
    "What's new?" : "Co je nového?",
    "Leave a rating on the Nextcloud App Store" : "Ohodnotit v katalogu aplikací pro Nextcloud",
    "What" : "Co",
    "Failed to count unavailable bookmarks" : "Nepodařilo se spočítat nedostupné záložky",
    "Failed to count archived bookmarks" : "Nepodařilo se spočítat archivované záložky",
    "Failed to count duplicated bookmarks" : "Nepodařilo se spočítat duplicitní záložky",
    "Failed to load bookmark" : "Záložku se nepodařilo načíst",
    "Failed to find existing bookmark" : "Nepodařilo se najít existující záložku",
    "Failed to create bookmark" : "Záložku se nepodařilo vytvořit",
    "Failed to save bookmark" : "Záložku se nepodařilo uložit",
    "Failed to move bookmark" : "Záložku se nepodařilo přesunout",
    "Failed to copy bookmark" : "Nepodařilo se zkopírovat záložku",
    "Failed to delete bookmark" : "Záložku se nepodařilo smazat",
    "Failed to rename tag" : "Štítek se nepodařilo přejmenovat",
    "Failed to load tags" : "Štítky se nepodařilo načíst",
    "Failed to load folders" : "Složky se nepodařilo načíst",
    "Failed to load deleted folders" : "Nepodařilo se načíst smazaná složky",
    "Failed to load deleted bookmarks" : "Nepodařilo se načíst smazané záložky",
    "Failed to delete folder" : "Složku se nepodařilo smazat",
    "Failed to move folder" : "Složku se nepodařilo přesunout",
    "Failed to create folder" : "Složku se nepodařilo vytvořit",
    "Failed to fetch bookmarks." : "Záložky se nepodařilo stáhnout.",
    "Failed to store setting" : "Nastavení se nepodařilo uložit",
    "Failed to load setting {key}" : "Nepodařilo se načíst nastavení {key}",
    "Failed to update share {shareId}" : "Nepodařilo se aktualizovat sdílení {shareId}",
    "Failed to delete share {shareId}" : "Nepodařilo se smazat sdílení {shareId}",
    "Create bookmarks for mentioned links" : "Vytvořit záložky z uvedených odkazů",
    "No links found in this message" : "V této zprávě nenalezeny žádné odkazy",
    "Bookmarks feed" : "Kanál záložek"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
